# <@LICENSE>
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to you under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at:
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# Modified form of MICROSOFT_EXECUTABLE Plugin
# Original file modified 08APR2008.  See:
# http://www.pettingers.org/annoyances/sa-rules.html for information 
# </@LICENSE>

=head1 NAME

Attachments - simple tests for common attachments

=head1 SYNOPSIS

  loadplugin     Mail::SpamAssassin::Plugin::Attachments

  body ATTACHMENT_PRESENT   eval:check_attach()


=head1 DESCRIPTION

The ATTACHMENT PRESENT rule works by checking attachment
boundaries in multi-part messages.

=cut

package Mail::SpamAssassin::Plugin::Attachments;

use Mail::SpamAssassin::Plugin;
use Mail::SpamAssassin::Util;
use strict;
use warnings;
use bytes;

use vars qw(@ISA);
@ISA = qw(Mail::SpamAssassin::Plugin);

# constructor: register the eval rule
sub new {
  my $class = shift;
  my $mailsaobject = shift;

  # some boilerplate...
  $class = ref($class) || $class;
  my $self = $class->SUPER::new($mailsaobject);
  bless ($self, $class);

  $self->register_eval_rule("check_attach");

  return $self;
}

sub check_attach {
  my ($self, $pms) = @_;

  _check_attachments(@_) unless exists $pms->{attachment_attach};

  return $pms->{attachment_attach};
}


sub _check_attachments {
  my ($self, $pms) = @_;

  $pms->{attachment_attach} = 0;

  # triggered here
  foreach my $p ($pms->{msg}->find_parts(qr/./, 1)) {
    my ($ctype, $boundary, $charset, $name) =
      Mail::SpamAssassin::Util::parse_content_type($p->get_header('content-type'));

    $name = lc $name || '';

    my $cte = lc $p->get_header('content-transfer-encoding') || '';
    $ctype = lc $ctype;

    if ($name && $name =~ /\.(?:pdf|zip)$/)
    {
      # file extension indicates an attachment type of interest
      $pms->{attachment_attach} = 1;
    }

  }
}

1;
